@@ -61,10 +61,11 @@ def get_annual_finData_by_symbol(category,symbol,country):
             df = get_annual_finData_balance(country)
         if category == "cashflow":
             df = get_annual_finData_cashflow(country)
+        df.columns = df.columns.str.lower()
         df = df.loc[symbol].transpose()
-        df = df.rename(index={'Fiscal_Year': 'Breakdown'})
-        df.columns = df.loc['Breakdown']
-        df = df.drop(['SimFinId', 'Currency', 'Breakdown', 'Fiscal_Period', 'Publish_Date', 'Restated_Date']) 
+        df = df.rename(index={'fiscal_year': 'breakdown'})
+        df.columns = df.loc['breakdown']
+        df = df.drop(['simfinid', 'currency', 'breakdown', 'fiscal_period', 'publish_date', 'restated_date'])
         return df
     except UnboundLocalError:
         print('Not a valid category')
@@ -86,78 +87,62 @@ def lineplot(dataframe,category):
     plt.figure(figsize=(20,9))
     sns.lineplot(data=plotData, x=plotData.columns[0],y=category)
 
-# def multiLineplot(dataframe,title):
-#     statement = dataframe
+def multiLineplot(dataframe,title):
+    plotData = dataframe.T
+    plotData = plotData.reset_index()
+    if len(str(plotData.iat[0, 0]))>4:
+        plotData['index']= pd.to_datetime(plotData['index'])
+    plotData = plotData.sort_values(plotData.columns[0])
 
-#     plotData = statement.T
-#     plotData = plotData.reset_index()
-#     #plotData.iloc[:, 1]= pd.to_datetime(plotData.iloc[:, 1])
-#     plotData = plotData.sort_values(plotData.columns[0])
+    columnsList = list(plotData.columns.values)
+    graphRowCount=math.ceil(len(plotData.columns)/3)
+    fig = plt.figure(figsize=(30,45))
+    fig.suptitle(title, fontsize=30)
 
-#     columnsList = list(plotData.columns.values)
-#     graphRowCount=math.ceil(len(plotData.columns)/3)
-#     fig = plt.figure(figsize=(30,45))
-#     fig.suptitle(title, fontsize=30)
+    for x in range(1, len(columnsList)):
+        plotNumber = 'ax'+str(x)
+        colname = plotData.columns[x]
 
-#     for x in range(1, len(columnsList)):
-#         plotNumber = 'ax'+str(x)
-#         colname = plotData.columns[x]
+        plotNumber = fig.add_subplot(graphRowCount,3,x)
+        plotNumber.set_title(colname)
+        plotNumber.plot(plotData.iloc[:, 1],
+             plotData[colname])
+        plt.xticks(rotation=45)
 
-#         plotNumber = fig.add_subplot(graphRowCount,3,x)
-#         plotNumber.set_title(colname)
-#         plotNumber.plot(plotData.iloc[:, 1],
-#              plotData[colname])
-#         plt.xticks(rotation=45)
-
-#     plt.show()
+    plt.show()
 
 def calculateMetrics(balanceSheet,incomeStatement):
-
-    balanceSheet = pd.read_csv(balanceSheet)
-    incomeStatement = pd.read_csv(incomeStatement)
-
-    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace(' ', '_')
-    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace(',', '')
-    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace('&', '')
-    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace(' ', '_')
-    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace(',', '')
-    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace('&', '')
-    balanceSheet['Breakdown'] = balanceSheet['Breakdown'].str.lower()
-    incomeStatement['Breakdown'] = incomeStatement['Breakdown'].str.lower()
-    balanceSheet = balanceSheet.set_index('Breakdown')
-    incomeStatement = incomeStatement.set_index('Breakdown')
-    balanceSheet=balanceSheet.abs()
-    incomeStatement=incomeStatement.abs()
+    balanceSheet=balanceSheet
+    incomeStatement=incomeStatement
 
     frames = [balanceSheet, incomeStatement]
     Ratio = pd.DataFrame()
     dataframeForRatio = pd.concat(frames)
-    dataframeForRatio = dataframeForRatio.drop_duplicates()
     dataframeForRatio = dataframeForRatio.T
-    dataframeForRatio['average_inventory'] = dataframeForRatio['inventory'].mean()
-    dataframeForRatio['average_accounts_receivable'] = dataframeForRatio['net_receivables'].mean()
+    dataframeForRatio['average_inventory'] = dataframeForRatio['inventories'].mean()
+    dataframeForRatio['average_accounts_receivable'] = dataframeForRatio['accounts_&_notes_receivable'].mean()
 
     #Liquidity Ratios
-    Ratio['quick_ratio'] = (dataframeForRatio['cash_and_cash_equivalents']+dataframeForRatio['net_receivables']+dataframeForRatio['short_term_investments'])/dataframeForRatio['total_current_liabilities']
+    #Ratio['quick_ratio'] = (dataframeForRatio['Cash,_Cash_Equivalents_&_Short_Term_Investments']+dataframeForRatio['Accounts_&_Notes_Receivable']+dataframeForRatio['short_term_investments'])/dataframeForRatio['Total_Current_Liabilities']
     Ratio['acid-test_ratio'] = dataframeForRatio['total_current_assets']/dataframeForRatio['total_current_liabilities']
-    Ratio['cash_ratio'] = (dataframeForRatio['total_current_assets']-dataframeForRatio['inventory'])/dataframeForRatio['total_current_liabilities']
+    Ratio['cash_ratio'] = (dataframeForRatio['total_current_assets']-dataframeForRatio['inventories'])/dataframeForRatio['total_current_liabilities']
 
     #Leverage Financial Ratios
     Ratio['debt_ratio'] = dataframeForRatio['total_liabilities']/(dataframeForRatio['total_assets']-dataframeForRatio['total_liabilities'])
-    Ratio['interest_coverage_ratio'] = dataframeForRatio['gross_profit']/dataframeForRatio['interest_expense']
+    Ratio['interest_coverage_ratio'] = dataframeForRatio['gross_profit']/dataframeForRatio['interest_expense,_net']
     #Ratio['debt_service_coverage_ratio'] = dataframeForRatio['gross_profit']/dataframeForRatio['']
 
     #Efficiency Ratios
-    Ratio['asset_turnover_ratio'] = dataframeForRatio['total_revenue']/dataframeForRatio['total_assets']
+    Ratio['asset_turnover_ratio'] = dataframeForRatio['revenue']/dataframeForRatio['total_assets']
     Ratio['inventory_turnover_ratio'] = dataframeForRatio['cost_of_revenue']/dataframeForRatio['average_inventory']
-    Ratio['receivables_turnover_ratio'] = dataframeForRatio['total_revenue']/dataframeForRatio['average_accounts_receivable']
+    Ratio['receivables_turnover_ratio'] = dataframeForRatio['revenue']/dataframeForRatio['average_accounts_receivable']
     Ratio['days_sales_in_inventory_ratio'] = 365/Ratio['inventory_turnover_ratio']
 
     #Profitability Ratios
-    Ratio['gross_margin_ratio'] = dataframeForRatio['gross_profit']/dataframeForRatio['total_revenue']
-    Ratio['operating_margin_ratio'] = dataframeForRatio['net_income']/dataframeForRatio['total_revenue']
-    Ratio['return_on_assets_ratio'] = dataframeForRatio['net_income']/dataframeForRatio['total_revenue']
-    Ratio['return_on_equity_ratio'] = dataframeForRatio['net_income']/(dataframeForRatio['total_revenue']-dataframeForRatio['total_liabilities'])
+    Ratio['gross_margin_ratio'] = dataframeForRatio['gross_profit']/dataframeForRatio['revenue']
+    Ratio['operating_margin_ratio'] = dataframeForRatio['net_income']/dataframeForRatio['revenue']
+    Ratio['return_on_assets_ratio'] = dataframeForRatio['net_income']/dataframeForRatio['revenue']
+    Ratio['return_on_equity_ratio'] = dataframeForRatio['net_income']/(dataframeForRatio['revenue']-dataframeForRatio['total_liabilities'])
 
     Ratio = Ratio.T
     Ratio = Ratio.round(4)
@@ -185,8 +170,8 @@ def bulletChart(file,item):
     
     fig.show()
 
-def horizontalAnalysisLastTwo(file):
-    statement = prep_dataframe(file)
+def horizontalAnalysisLastTwo(dataframe):
+    statement = dataframe
     statement = statement.reindex(sorted(statement.columns), axis=1)
     statement_lastPeriods = statement[statement.columns[-2:]]
     statement_lastPeriods_lastColName = statement[statement_lastPeriods.columns[-1:]].columns.values[0]
@@ -196,4 +181,4 @@ def horizontalAnalysisLastTwo(file):
     statement_lastPeriods = statement_lastPeriods.dropna()
     statement_lastPeriods['Percentage(Increased/Decreased)'] = pd.Series(["{0:.2f}%".format(val * 100) for val in statement_lastPeriods['Percentage(Increased/Decreased)']], index = statement_lastPeriods.index)
     statement_lastPeriods.to_csv('horizontalAnalysisLastTwo.csv')
-    print("Horizontal Analysis with Last two Periods", statement_lastPeriods, sep='\n')
+    print("Horizontal Analysis with Last two Periods", statement_lastPeriods, sep='\n')
\ No newline at end of file
